# -*- coding: utf-8 -*-
import pickle

def save(data, filename='mypersist.pkl', prefix = 'en'):
	filename = prefix + filename
	output = open(filename, 'wb')
	pickle.dump(data, output)
	output.close()

def load(filename='mypersist.pkl', prefix = 'en'):
	filename = prefix + filename
	pkl_file = open(filename, 'rb')
	data = pickle.load(pkl_file)
	return data



from setuptools import setup

setup(name='phasepersist',
      version='0.1',
      description='Load and save python stuff in pickle files.',
      url='http://github.com/phasemix/phasepersist',
      author='Roberto Allende',
      author_email='rallende@gmail.com',
      license='Apache 2.0',
      packages=['phasepersist'],
      zip_safe=False)